@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 import os, sys
 from PyQt4 import QtGui, QtCore
 from tubeMap_window import *
@@ -12,10 +13,12 @@ class TubeMapDisplay(QtGui.QMainWindow):
     def setupWindow(self):
         #self.ui.labelTubeMap.setText("Hello")
         self.pic = QtGui.QLabel(self)
-        self.pic.setGeometry(0,0,800,400)
+        #self.pic.setGeometry(0,0,800,400)
         #self.pic.setPixmap(QtGui.QPixmap(os.getcwd() + "/tubemap.gif"))
         self.pic.setPixmap(QtGui.QPixmap("/opt/tflapp/tubemap.png"))
         self.scrollArea = QtGui.QScrollArea(self)
         self.scrollArea.setWidget(self.pic)
-        self.scrollArea.setGeometry(QtCore.QRect(0, 0, 800, 400))
+        self.scrollArea.setGeometry(QtCore.QRect(0, 0, 800, 424))
         self.scrollArea.setWidgetResizable(True)
+        parent = self.nativeParentWidget()
+        parent.setAttribute(QtCore.Qt.WA_Maemo5ShowProgressIndicator, False )
